@@ -72,7 +72,7 @@ class DataType:
             return True
 
     @classmethod
-    def is_subtype_of(cls, super_type: type, allow_same: bool = True):
+    def issubtype(cls, super_type: type, allow_same: bool = True):
         """Check to see whether datatype class is a subtype of a given super class.
         In this case the subtype is expected to be able to be treated as if it was
         the super class.
@@ -252,14 +252,14 @@ class DataType:
                         )
                     except AttributeError:
                         try:
-                            qualified = cls.generically_qualified_by_name[
+                            qualified = cls.generically_qualifies_by_name[
                                 qualified_name
                             ]
                         except KeyError:
                             raise FormatRecognitionError(
                                 f"Could not load qualified class '{qualified_name}' from "
                                 f"fileformats.{namespace} or list of generic types "
-                                f"({list(cls.generically_qualified_by_name)}), "
+                                f"({list(cls.generically_qualifies_by_name)}), "
                                 f"corresponding to MIME, or MIME-like, type {mime_string}"
                             ) from None
                     klass = qualified[qualifiers]
@@ -271,16 +271,16 @@ class DataType:
         return klass
 
     @classproperty
-    def generically_qualified_by_name(cls):
-        if cls._generically_qualified_by_name is None:
-            cls._generically_qualified_by_name = {
+    def generically_qualifies_by_name(cls):
+        if cls._generically_qualifies_by_name is None:
+            cls._generically_qualifies_by_name = {
                 to_mime_format_name(f.__name__): f
                 for f in FileSet.all_formats
-                if getattr(f, "generically_qualified", False)
+                if getattr(f, "generically_qualifies", False)
             }
-        return cls._generically_qualified_by_name
+        return cls._generically_qualifies_by_name
 
-    _generically_qualified_by_name = None  # Register all generically qualified types
+    _generically_qualifies_by_name = None  # Register all generically qualified types
 
 
 @attrs.define
@@ -335,10 +335,9 @@ class FileSet(DataType):
         missing = [p for p in fspaths if not p or not p.exists()]
         if missing:
             missing_str = "\n".join(str(p) for p in missing)
-            all_str = "\n".join(str(p) for p in fspaths)
             msg = (
                 f"The following file system paths provided to {type(self)} do not "
-                f"exist:\n{missing_str}\n\nFrom full list:\n{all_str}"
+                f"exist:\n\n{missing_str}\n\n"
             )
             present_parents = set()
             for fspath in missing:
@@ -352,9 +351,6 @@ class FileSet(DataType):
                 msg += "\n".join(str(p) for p in parent.iterdir())
             raise FileNotFoundError(msg)
 
-    def __iter__(self):
-        return iter(self.fspaths)
-
     @property
     def metadata(self):
         if self._metadata is None and hasattr(self, "load_metadata"):
@@ -631,7 +627,7 @@ class FileSet(DataType):
         FileFormatConversionError
             ambiguous (i.e. more than one) converters found between source and dest format
         """
-        if source_format.is_subtype_of(cls):
+        if source_format.issubtype(cls):
             return None
         converters = (
             cls.get_converters_dict()
@@ -731,7 +727,7 @@ class FileSet(DataType):
         available = []
         for src_frmt, converter in converters_dict.items():
             if len(converter) == 2:  # Ignore converters with wildcards at this point
-                if source_format.is_subtype_of(src_frmt):
+                if source_format.issubtype(src_frmt):
                     available.append(converter)
         if not available and hasattr(source_format, "unqualified"):
             available = SubtypeVar.get_converter_tuples(
