@@ -163,7 +163,7 @@ class WithSideCars(WithAdjacentFiles):
 
 class WithQualifiers:
     """Mixin class for adding the ability to qualify the format class to designate the
-    type of information stored within the format, e.g. ``Directory[Png, Gif]`` for a
+    type of information stored within the format, e.g. ``DirectoryContaining[Png, Gif]`` for a
     directory containing PNG and GIF files, ``Zip[DataFile]`` for a zipped data file,
     ``Array[Integer]`` for an array containing integers, or DicomDir[T1w, Brain] for a
     T1-weighted MRI scan of the brain in DICOM format.
@@ -217,7 +217,7 @@ class WithQualifiers:
     multiple_qualifiers = True
     allowed_qualifiers = None
     ordered_qualifiers = False
-    generically_qualified = False
+    generically_qualifies = False
 
     def __attrs_pre_init__(self):
         if self.wildcard_qualifiers():
@@ -253,7 +253,7 @@ class WithQualifiers:
             not_allowed = [
                 q
                 for q in qualifiers
-                if not any(q.is_subtype_of(t) for t in cls.allowed_qualifiers)
+                if not any(q.issubtype(t) for t in cls.allowed_qualifiers)
             ]
             if not_allowed:
                 raise FileFormatsError(
@@ -359,11 +359,11 @@ class WithQualifiers:
                         if len(to_match) > 1:
                             wildcard_match = False
                         else:
-                            wildcard_match = source_format.is_subtype_of(to_match[0])
+                            wildcard_match = source_format.issubtype(to_match[0])
                     # Attempt template to template conversion match
                     elif getattr(
                         source_format, "is_qualified", False
-                    ) and source_format.unqualified.is_subtype_of(
+                    ) and source_format.unqualified.issubtype(
                         template_source_format.unqualified
                     ):
                         assert cls.wildcard_qualifiers(
@@ -393,10 +393,10 @@ class WithQualifiers:
                                             wildcard_match = False
                                             break
                                         else:
-                                            if not actual.is_subtype_of(reference):
+                                            if not actual.issubtype(reference):
                                                 wildcard_match = False
                                                 break
-                                    elif not actual.is_subtype_of(template):
+                                    elif not actual.issubtype(template):
                                         wildcard_match = False
                                         break
                         else:
@@ -425,14 +425,14 @@ class WithQualifiers:
         return available_converters
 
     @classmethod
-    def is_subtype_of(cls, super_type: type):
-        if super().is_subtype_of(super_type):
+    def issubtype(cls, super_type: type):
+        if super().issubtype(super_type):
             return True
         # Check to see whether the unqualified types are equivalent
         if (
             not cls.is_qualified
             or not getattr(super_type, "is_qualified", False)
-            or not cls.unqualified.is_subtype_of(super_type.unqualified)
+            or not cls.unqualified.issubtype(super_type.unqualified)
         ):
             return False
         if cls.ordered_qualifiers:
@@ -440,7 +440,7 @@ class WithQualifiers:
                 is_subtype = False
             else:
                 is_subtype = all(
-                    q.is_subtype_of(s)
+                    q.issubtype(s)
                     for q, s in zip(cls.qualifiers, super_type.qualifiers)
                 )
         else:
@@ -448,7 +448,7 @@ class WithQualifiers:
                 is_subtype = True
             else:
                 is_subtype = all(
-                    any(q.is_subtype_of(s) for q in cls.qualifiers)
+                    any(q.issubtype(s) for q in cls.qualifiers)
                     for s in super_type.qualifiers
                 )
         return is_subtype
@@ -501,7 +501,7 @@ class WithQualifiers:
                     f
                     for f in cls.converters
                     if (
-                        source_format.unqualified.is_subtype_of(f.unqualified)
+                        source_format.unqualified.issubtype(f.unqualified)
                         and f.non_wildcard_qualifiers()
                         == source_format.non_wildcard_qualifiers()
                     )
@@ -526,7 +526,7 @@ class WithQualifiers:
         namespace"""
         if cls.is_qualified:
             namespaces = set(t.namespace for t in cls.qualifiers)
-            if not cls.generically_qualified:
+            if not cls.generically_qualifies:
                 namespaces.add(cls.unqualified.namespace)
             if len(namespaces) == 1:
                 return next(iter(namespaces))
@@ -535,7 +535,7 @@ class WithQualifiers:
                     "Cannot create reversible MIME type for because did not find a "
                     f"common namespace between all qualifiers {list(cls.qualifiers)}"
                 )
-                if cls.generically_qualified:
+                if cls.generically_qualifies:
                     msg += (
                         f" and (non genericly qualified) base class {cls.unqualified}"
                     )
