@@ -4,7 +4,7 @@ import pydra.mark
 from fileformats.core import from_mime, DataType, FileSet
 from fileformats.core.mark import converter
 from fileformats.archive import Zip
-from fileformats.generic import Directory
+from fileformats.generic import DirectoryContaining
 from fileformats.field import Array, Integer, Decimal, Text, Boolean
 from fileformats.core.exceptions import (
     FileFormatsError,
@@ -51,26 +51,26 @@ def test_qualified_equivalence():
 
 def test_subtype_testing():
 
-    assert G.is_subtype_of(F)
-    assert not F.is_subtype_of(G)
-    assert J.is_subtype_of(J)
-    assert J.is_subtype_of(H)
-    assert J[A].is_subtype_of(J)
-    assert not H[A].is_subtype_of(F)
-    assert not H[A].is_subtype_of(F[A])
-    assert J[A, B].is_subtype_of(J[A])
-    assert not J[B].is_subtype_of(J[A])
-    assert not J[A].is_subtype_of(J[A, B])
-    assert J[A].is_subtype_of(H[A])
-    assert J[A, B, C].is_subtype_of(H[A, B])
-    assert not J[A].is_subtype_of(H[B])
-    assert FileSet.is_subtype_of(DataType)
-    assert SpecificFileSet.is_subtype_of(SpecificDataType)
-    assert F[SpecificFileSet].is_subtype_of(F[SpecificDataType])
-    assert L[A, E].is_subtype_of(L[A, C])
-    assert not L[E, A].is_subtype_of(L[A, C])
-    assert K[A, E, B].is_subtype_of(K[A, C, B])
-    assert N[J, K].is_subtype_of(N[J, H])  # J is subclass of H,
+    assert G.issubtype(F)
+    assert not F.issubtype(G)
+    assert J.issubtype(J)
+    assert J.issubtype(H)
+    assert J[A].issubtype(J)
+    assert not H[A].issubtype(F)
+    assert not H[A].issubtype(F[A])
+    assert J[A, B].issubtype(J[A])
+    assert not J[B].issubtype(J[A])
+    assert not J[A].issubtype(J[A, B])
+    assert J[A].issubtype(H[A])
+    assert J[A, B, C].issubtype(H[A, B])
+    assert not J[A].issubtype(H[B])
+    assert FileSet.issubtype(DataType)
+    assert SpecificFileSet.issubtype(SpecificDataType)
+    assert F[SpecificFileSet].issubtype(F[SpecificDataType])
+    assert L[A, E].issubtype(L[A, C])
+    assert not L[E, A].issubtype(L[A, C])
+    assert K[A, E, B].issubtype(K[A, C, B])
+    assert N[J, K].issubtype(N[J, H])  # J is subclass of H,
 
 
 def test_qualifier_fails():
@@ -150,12 +150,12 @@ def test_ordered_qualifier_converters():
 
 def test_mime_rountrips():
 
-    assert Directory[F].mime_like == "testing/f+directory"
-    assert from_mime("testing/f+directory") is Directory[F]
+    assert DirectoryContaining[F].mime_like == "testing/f+directory-containing"
+    assert from_mime("testing/f+directory-containing") is DirectoryContaining[F]
 
     # Directory is unordered so sort qualifiers to create unique mime
-    assert Directory[H, F].mime_like == "testing/f.h+directory"
-    assert from_mime("testing/f.h+directory") is Directory[F, H]
+    assert DirectoryContaining[H, F].mime_like == "testing/f.h+directory-containing"
+    assert from_mime("testing/f.h+directory-containing") is DirectoryContaining[F, H]
 
     # K is ordered
     assert K[B, A].mime_like == "testing/b.a+k"
