@@ -1,5 +1,3 @@
-from ..core import __version__, import_converters
+from ..core import __version__
 from .raster import RasterImage, Bitmap, Gif, Jpeg, Png, Tiff
 from .vector import VectorImage, Svg
-
-import_converters(__name__)
